/*
** Module   : CommonErrorStatus.java
** Abstract : Define all APIs available via the ERROR-STATUS system handle.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130112 Created initial version.
** 002 CA  20130216 Added support for ERROR-OBJECT-DETAIL attribute.
*/

package com.goldencode.p2j.util;

/**
 * Exposes the following methods or attributes from the ERROR-STATUS handle:
 * <table>
 * <tr>
 *    <th>ERROR-STATUS attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>ERROR</td>
 *    <td> {@link #isError()} and {@link #setError(boolean)} </td>
 * </tr>
 * <tr>
 *    <td>ERROR-OBJECT-DETAIL</td>
 *    <td> {@link #getErrorObjectDetail()} </td>
 * </tr>
 * <tr>
 *    <td>NUM-MESSAGES</td>
 *    <td>{@link #numErrors()}</td>
 * </tr>
 * <tr>
 *    <td>GET-MESSAGE(n)</td>
 *    <td>{@link #getErrorText(int)} and {@link #getErrorText(integer)}</td>
 * </tr>
 * <tr>
 *    <td>GET-NUMBER(n)</td>
 *    <td>{@link #getErrorNumber(int)} and {@link #getErrorNumber(integer)}
 *    </td>
 * </tr>
 * </table>
 * This interface is used as a returned type by the 
 * {@link handle#unwrapErrorStatus(handle)} API, which, depending on the 
 * handle's state, it either returns an {@link ErrorManager#asHandle()} 
 * instance or an dynamic proxy using {@link handle#invalidAttrAccessProxy} 
 */
public interface CommonErrorStatus
extends CommonHandle
{
   /**
    * Returns the state of the error flag which was set at the last call to
    * {@link ErrorManager#silentErrorDisable} or if 
    * {@link ErrorManager#silentErrorEnable} has never been called, this 
    * will return <code>false</code>.
    *
    * @return    Current state of the error flag.
    */
   public logical isError();
   
   /**
    * Sets the <code>error</code> variable.
    *
    * @param    value
    *           The new state of the variable.
    */
   public void setError(boolean value);    
   
   /**
    * Returns the Progress compatible error text associated with the error
    * entry at the given index in the error list.  If the list is empty or
    * if the index is invalid, an empty string "" is returned.
    *
    * @param    index
    *           Position in the error list from which to return the entry.
    *
    * @return   The error text at that index or the empty string "" if the
    *           list is empty or if the index is invalid.
    */
   public character getErrorText(integer index);
   
   /**
    * Returns the Progress compatible error text associated with the error
    * entry at the given index in the error list.  If the list is empty or
    * if the index is invalid, an empty string "" is returned.
    *
    * @param    index
    *           Position in the error list from which to return the entry.
    *
    * @return   The error text at that index or the empty string "" if the
    *           list is empty or if the index is invalid.
    */
   public character getErrorText(int index);

   /**
    * Returns the number of the errors (recorded in the error list) which
    * have occurred since the last call to 
    * {@link ErrorManager#silentErrorEnable}.
    *
    * @return    Current number of errors in the error list if silent mode
    *            has been enabled. This will be 0 if no errors have occurred  
    *            since the last <code>silentErrorEnable</code> call OR if  
    *            <code>silentErrorEnable</code> has never been called.
    */
   public integer numErrors();
   
   /**
    * Returns the Progress compatible error number associated with the error
    * entry at the given index in the error list.  If the list is empty or
    * if the index is invalid, 0 is returned.
    *
    * @param    index
    *           Position in the error list from which to return the entry.
    *
    * @return   The error number at that index or 0 if the list is empty or
    *           if the index is invalid.
    */
   public integer getErrorNumber(integer index);
   
   /**
    * Returns the Progress compatible error number associated with the error
    * entry at the given index in the error list.  If the list is empty or
    * if the index is invalid, 0 is returned.
    *
    * @param    index
    *           Position in the error list from which to return the entry.
    *
    * @return   The error number at that index or 0 if the list is empty or
    *           if the index is invalid.
    */
   public integer getErrorNumber(int index);

   /**
    * Returns a handle for the ERROR-OBJECT-DETAIL attribute, set in cases of SOAP-related faults.
    * 
    * @return   See above.
    */
   public handle getErrorObjectDetail();
}
